==> oc-2.1.7.zip: oc/main.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ----------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2010 Olivier Meunier and contributors
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK ------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Username:'] = 'Nom d\'utilizaire:';
$GLOBALS['__l10n']['Password:'] = 'Mot de pas:';
$GLOBALS['__l10n']['Login:'] = 'Login:';
$GLOBALS['__l10n']['Email:'] = 'E-meil:';
$GLOBALS['__l10n']['login'] = 'login';
$GLOBALS['__l10n']['Blogs'] = 'Blògs';
$GLOBALS['__l10n']['Blog ID:'] = 'Blòg ID:';
$GLOBALS['__l10n']['Blog URL:'] = 'Blòg URL:';
$GLOBALS['__l10n']['save'] = 'salvar';
$GLOBALS['__l10n']['Warning'] = 'Avertiment';
$GLOBALS['__l10n']['title'] = 'títol';
$GLOBALS['__l10n']['Title, Date'] = 'Títol, Data';
$GLOBALS['__l10n']['Title, Country, Date'] = 'Títol, Païs, Data';
$GLOBALS['__l10n']['Title, City, Country, Date'] = 'Títol, Ciutat , Païs, Data';
$GLOBALS['__l10n']['Accept comments'] = 'Acceptar los comentaris';
$GLOBALS['__l10n']['User name:'] = 'Nom d\'utilizaire:';
$GLOBALS['__l10n']['by %s'] = 'per %s';
$GLOBALS['__l10n']['Search:'] = 'Recercar:';
$GLOBALS['__l10n']['Title:'] = 'Títol:';
$GLOBALS['__l10n']['Name'] = 'Nom';
$GLOBALS['__l10n']['URL:'] = 'URL:';
$GLOBALS['__l10n']['Description:'] = 'Descriveson:';
$GLOBALS['__l10n']['Save'] = 'Salvar';
$GLOBALS['__l10n']['Date:'] = 'Data:';
$GLOBALS['__l10n']['Author:'] = 'Fasedor(a):';
$GLOBALS['__l10n']['Status:'] = 'Estatut:';
$GLOBALS['__l10n']['Comment:'] = 'Coment:';
$GLOBALS['__l10n']['comment'] = 'coment';
$GLOBALS['__l10n']['Date'] = 'Data';
$GLOBALS['__l10n']['Author'] = 'Fasedor(a)';
$GLOBALS['__l10n']['publish'] = 'escridar';
$GLOBALS['__l10n']['Documentation'] = 'Documentason';
$GLOBALS['__l10n']['Errors:'] = 'Errors';
$GLOBALS['__l10n']['Firstname:'] = 'Reirenom:';
$GLOBALS['__l10n']['Name:'] = 'Nom:';
$GLOBALS['__l10n']['Error:'] = 'Error:';
$GLOBALS['__l10n']['cancel'] = 'dirimir';
$GLOBALS['__l10n']['yes'] = 'òc';
$GLOBALS['__l10n']['Private'] = 'Privat';
$GLOBALS['__l10n']['send'] = 'mandar';
$GLOBALS['__l10n']['open'] = 'dobrir';
$GLOBALS['__l10n']['Left'] = 'Esquèr';
$GLOBALS['__l10n']['Right'] = 'Drecha';
$GLOBALS['__l10n']['Center'] = 'Mijòl';
$GLOBALS['__l10n']['Cancel'] = 'Dirimir';
$GLOBALS['__l10n']['Insert'] = 'Enserir';
$GLOBALS['__l10n']['Version'] = 'Revirada';
$GLOBALS['__l10n']['Description'] = 'Descriveson';
$GLOBALS['__l10n']['Add a link'] = 'Apondre un ligam';
$GLOBALS['__l10n']['Link URL:'] = 'Ligam URL:';
$GLOBALS['__l10n']['insert'] = 'enserir';
$GLOBALS['__l10n']['Category:'] = 'Categòria:';
$GLOBALS['__l10n']['remove'] = 'escafar';
$GLOBALS['__l10n']['Excerpt:'] = 'Estrach:';
$GLOBALS['__l10n']['Content:'] = 'Contengut:';
$GLOBALS['__l10n']['preview'] = 'previstalejar';
$GLOBALS['__l10n']['Title'] = 'Títol';
$GLOBALS['__l10n']['Category'] = 'Categòria';
$GLOBALS['__l10n']['Month:'] = 'Mes:';
$GLOBALS['__l10n']['Lang:'] = 'Lenga:';
$GLOBALS['__l10n']['Search'] = 'Recercar';
$GLOBALS['__l10n']['Warning:'] = 'Avertiment:';
$GLOBALS['__l10n']['Firstname'] = 'Reirenom';
$GLOBALS['__l10n']['Delete'] = 'Supremir';
$GLOBALS['__l10n']['Blog:'] = 'Blòg:';
$GLOBALS['__l10n']['Blogs:'] = 'Blògs:';
$GLOBALS['__l10n']['User:'] = 'Utilizaire:';
$GLOBALS['__l10n']['Help'] = 'Ajuda';
$GLOBALS['__l10n']['help'] = 'ajuda';
$GLOBALS['__l10n']['close'] = 'barrar';
$GLOBALS['__l10n']['now'] = 'ara';
$GLOBALS['__l10n']['source'] = 'capcièr';
$GLOBALS['__l10n']['Paragraph'] = 'Paragraf';
$GLOBALS['__l10n']['Level 1 header'] = 'Sostítol nivèl 1';
$GLOBALS['__l10n']['Level 2 header'] = 'Sostítol nivèl 2';
$GLOBALS['__l10n']['Level 3 header'] = 'Sostítol nivèl 3';
$GLOBALS['__l10n']['Level 4 header'] = 'Sostítol nivèl 4';
$GLOBALS['__l10n']['Level 5 header'] = 'Sostítol nivèl 5';
$GLOBALS['__l10n']['Level 6 header'] = 'Sostítol nivèl 6';
$GLOBALS['__l10n']['Strong emphasis'] = 'Tèxt en gras';
$GLOBALS['__l10n']['Emphasis'] = 'Tèxt en italica';
$GLOBALS['__l10n']['Link'] = 'Ligam';
$GLOBALS['__l10n']['URL?'] = 'URL?';
$GLOBALS['__l10n']['Language?'] = 'Lenga?';
$GLOBALS['__l10n']['External image'] = 'Ligam fichièr media';
$GLOBALS['__l10n']['Media chooser'] = 'Fichièr media intèrn';
$GLOBALS['__l10n']['Clean'] = 'Boissar';
$GLOBALS['__l10n']['Upload'] = 'Envïar';
$GLOBALS['__l10n']['Type'] = 'Tipe';
$GLOBALS['__l10n']['System'] = 'Sistèm';
$GLOBALS['__l10n']['Blog'] = 'Blòg';
$GLOBALS['__l10n']['administrator'] = 'administrador';
?>

==> oc-2.2.2.zip: oc/main.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2010 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Username:'] = 'Nom d\'utilizaire:';
$GLOBALS['__l10n']['Password:'] = 'Mot de pas:';
$GLOBALS['__l10n']['Email:'] = 'E-meil:';
$GLOBALS['__l10n']['change'] = 'dirimir';
$GLOBALS['__l10n']['login'] = 'login';
$GLOBALS['__l10n']['Blogs'] = 'Blògs';
$GLOBALS['__l10n']['Blog ID:'] = 'Blòg ID:';
$GLOBALS['__l10n']['Blog URL:'] = 'Blòg URL:';
$GLOBALS['__l10n']['save'] = 'salvar';
$GLOBALS['__l10n']['Warning'] = 'Avertiment';
$GLOBALS['__l10n']['title'] = 'títol';
$GLOBALS['__l10n']['Title'] = 'Títol';
$GLOBALS['__l10n']['Title, Date'] = 'Títol, Data';
$GLOBALS['__l10n']['Title, Country, Date'] = 'Títol, Païs, Data';
$GLOBALS['__l10n']['Title, City, Country, Date'] = 'Títol, Ciutat , Païs, Data';
$GLOBALS['__l10n']['Accept comments'] = 'Acceptar los comentaris';
$GLOBALS['__l10n']['User name:'] = 'Nom d\'utilizaire:';
$GLOBALS['__l10n']['by %s'] = 'per %s';
$GLOBALS['__l10n']['version %s'] = 'Revirada';
$GLOBALS['__l10n']['Blog appearance'] = 'Blògs';
$GLOBALS['__l10n']['Search:'] = 'Recercar:';
$GLOBALS['__l10n']['Categories list'] = 'Categòria';
$GLOBALS['__l10n']['URL:'] = 'URL:';
$GLOBALS['__l10n']['Title:'] = 'Títol:';
$GLOBALS['__l10n']['Save'] = 'Salvar';
$GLOBALS['__l10n']['Description:'] = 'Descriveson:';
$GLOBALS['__l10n']['Category parent'] = 'Categòria';
$GLOBALS['__l10n']['Category sibling'] = 'Categòria';
$GLOBALS['__l10n']['after'] = 'Data';
$GLOBALS['__l10n']['Date:'] = 'Data:';
$GLOBALS['__l10n']['Author:'] = 'Fasedor(a):';
$GLOBALS['__l10n']['Status:'] = 'Estatut:';
$GLOBALS['__l10n']['Comment:'] = 'Coment:';
$GLOBALS['__l10n']['comment'] = 'coment';
$GLOBALS['__l10n']['Date'] = 'Data';
$GLOBALS['__l10n']['Author'] = 'Fasedor(a)';
$GLOBALS['__l10n']['publish'] = 'escridar';
$GLOBALS['__l10n']['Documentation'] = 'Documentason';
$GLOBALS['__l10n']['Content:'] = 'Contengut:';
$GLOBALS['__l10n']['Category:'] = 'Categòria:';
$GLOBALS['__l10n']['save and publish'] = 'escridar';
$GLOBALS['__l10n']['Errors:'] = 'Errors';
$GLOBALS['__l10n']['First Name:'] = 'Reirenom:';
$GLOBALS['__l10n']['Last Name:'] = 'Nom:';
$GLOBALS['__l10n']['Blog address:'] = 'Blògs:';
$GLOBALS['__l10n']['Administration interface:'] = 'administrador';
$GLOBALS['__l10n']['Language'] = 'Lenga?';
$GLOBALS['__l10n']['Delete'] = 'Supremir';
$GLOBALS['__l10n']['Language:'] = 'Lenga?';
$GLOBALS['__l10n']['Error:'] = 'Error:';
$GLOBALS['__l10n']['cancel'] = 'dirimir';
$GLOBALS['__l10n']['yes'] = 'òc';
$GLOBALS['__l10n']['Private'] = 'Privat';
$GLOBALS['__l10n']['send'] = 'mandar';
$GLOBALS['__l10n']['open'] = 'dobrir';
$GLOBALS['__l10n']['Left'] = 'Esquèr';
$GLOBALS['__l10n']['Right'] = 'Drecha';
$GLOBALS['__l10n']['Center'] = 'Mijòl';
$GLOBALS['__l10n']['Height:'] = 'Drecha';
$GLOBALS['__l10n']['Cancel'] = 'Dirimir';
$GLOBALS['__l10n']['Insert'] = 'Enserir';
$GLOBALS['__l10n']['Version'] = 'Revirada';
$GLOBALS['__l10n']['Activate'] = 'Privat';
$GLOBALS['__l10n']['Add a link'] = 'Apondre un ligam';
$GLOBALS['__l10n']['Link URL:'] = 'Ligam URL:';
$GLOBALS['__l10n']['insert'] = 'enserir';
$GLOBALS['__l10n']['Preview entry'] = 'previstalejar';
$GLOBALS['__l10n']['remove'] = 'escafar';
$GLOBALS['__l10n']['Excerpt:'] = 'Estrach:';
$GLOBALS['__l10n']['Name:'] = 'Nom:';
$GLOBALS['__l10n']['Category'] = 'Categòria';
$GLOBALS['__l10n']['Publish'] = 'escridar';
$GLOBALS['__l10n']['Unpublish'] = 'escridar';
$GLOBALS['__l10n']['Change'] = 'Dirimir';
$GLOBALS['__l10n']['Change category'] = 'Categòria';
$GLOBALS['__l10n']['Month:'] = 'Mes:';
$GLOBALS['__l10n']['Lang:'] = 'Lenga:';
$GLOBALS['__l10n']['Search'] = 'Recercar';
$GLOBALS['__l10n']['Warning:'] = 'Avertiment:';
$GLOBALS['__l10n']['Username'] = 'Nom d\'utilizaire:';
$GLOBALS['__l10n']['Last Name'] = 'Nom';
$GLOBALS['__l10n']['First Name'] = 'Reirenom';
$GLOBALS['__l10n']['Blog:'] = 'Blòg:';
$GLOBALS['__l10n']['Blogs:'] = 'Blògs:';
$GLOBALS['__l10n']['User:'] = 'Utilizaire:';
$GLOBALS['__l10n']['Help'] = 'Ajuda';
$GLOBALS['__l10n']['help'] = 'ajuda';
$GLOBALS['__l10n']['close'] = 'barrar';
$GLOBALS['__l10n']['now'] = 'ara';
$GLOBALS['__l10n']['source'] = 'capcièr';
$GLOBALS['__l10n']['Paragraph'] = 'Paragraf';
$GLOBALS['__l10n']['Level 1 header'] = 'Sostítol nivèl 1';
$GLOBALS['__l10n']['Level 2 header'] = 'Sostítol nivèl 2';
$GLOBALS['__l10n']['Level 3 header'] = 'Sostítol nivèl 3';
$GLOBALS['__l10n']['Level 4 header'] = 'Sostítol nivèl 4';
$GLOBALS['__l10n']['Level 5 header'] = 'Sostítol nivèl 5';
$GLOBALS['__l10n']['Level 6 header'] = 'Sostítol nivèl 6';
$GLOBALS['__l10n']['Strong emphasis'] = 'Tèxt en gras';
$GLOBALS['__l10n']['Emphasis'] = 'Tèxt en italica';
$GLOBALS['__l10n']['Link'] = 'Ligam';
$GLOBALS['__l10n']['URL?'] = 'URL?';
$GLOBALS['__l10n']['Language?'] = 'Lenga?';
$GLOBALS['__l10n']['External image'] = 'Ligam fichièr media';
$GLOBALS['__l10n']['Media chooser'] = 'Fichièr media intèrn';
$GLOBALS['__l10n']['Clean'] = 'Boissar';
$GLOBALS['__l10n']['Upload'] = 'Envïar';
$GLOBALS['__l10n']['Type'] = 'Tipe';
$GLOBALS['__l10n']['System'] = 'Sistèm';
$GLOBALS['__l10n']['Blog'] = 'Blòg';
$GLOBALS['__l10n']['Languages'] = 'Lenga?';
$GLOBALS['__l10n']['administrator'] = 'administrador';
$GLOBALS['__l10n']['unknown'] = 'ara';
?>
